import json
import os
from glob import glob


def convert(_dir, version, edition ='pc'):
    with open(os.path.join(_dir, 'dataPaths.json')) as f:
        datapaths = json.load(f)
    data = _grabdata(_dir, datapaths[edition][version])
    ret = {}
    for datum in ('recipes', 'materials', 'protocol', 'version',
            'blockCollisionShapes', 'protocolComments'):
        if datum in data:
            ret[datum] = data[datum]
    for datum in ('blocks', 'items', 'windows', 'effects', 'particles',
            'biomes', 'instruments', 'enchantments', 'foods'):
        if datum in data:
            ret[datum] = _by_id(data[datum])
            ret[f"{datum}_name"] = _by_name(data[datum])
            ret[f"{datum}_list"] = data[datum]
    if 'entities' in data:
        ret['mobs'] = _by_id(_filter('type', 'mob', data['entities']))
        ret['objects'] = _by_id(_filter('type', 'object', data['entities']))
        ret['entities_name'] = _by_name(data['entities'])
        ret['entities_list'] = data['entities']


    def find_item_or_block(find):
        if isinstance(find, int):  # by id
            return find_by(find, ret['items'], ret['blocks'])
        else:  # by name
            return find_by(find, ret['items_name'], ret['blocks_name'])

    ret['find_item_or_block'] = find_item_or_block

    return ret


def _grabdata(_dir, datapaths):
    data = {}
    for category, folder in datapaths.items():
        with open(os.path.join(_dir, folder, f'{category}.json')) as fp:
            data[category] = json.load(fp)
    return data


def _by_id(data):
    return _by('id', data)


def _by_name(data):
    return _by('name', data)


def _by(key, data):
    return {item[key]: item for item in data}


def _filter(key, val, data):
    return [d for d in data if d[key] == val]


def find_by(key, *args):
    for arg in args:
        if key in arg:
            return arg[key]
    return None



import os
import sys

from minecraft_data.tools import convert


class mod(sys.modules[__name__].__class__):
    def __call__(self, version, edition = 'pc'):
        _dir = os.path.join(
            os.path.dirname(__file__), "data/data/"
        )
        return type(version, (object,), convert(_dir, version, edition))


sys.modules[__name__].__class__ = mod



import minecraft_data
# Java edition minecraft-data
mcd = minecraft_data("1.13")

print(mcd.version)

print(mcd.find_item_or_block(1))
print(mcd.find_item_or_block('stone'))

print(mcd.recipes['5'][0])

print(mcd.windows['minecraft:brewing_stand'])

print(mcd.effects_name['Haste'])

# Pocket Edition minecraft-data
mcd_pe = minecraft_data("1.0", "pe")

print(mcd_pe.version)
print(mcd_pe.find_item_or_block('stone'))



import os

from distutils.core import setup

from setuptools import find_packages

def package_files(directory):
    paths = []
    for (path, directories, filenames) in os.walk(directory):
        for filename in filenames:
            paths.append(os.path.join('..', path, filename))
    return paths

extra_files = package_files('minecraft_data/data/data')

setup(
    name='minecraft_data',
    description='Provide easy access to minecraft data in python',
    license='MIT',
    long_description=open('README.rst').read(),
    version='2.67.0',
    maintainer='Romain Beaumont',
    maintainer_email='romain.rom1@gmail.com',
    url='https://github.com/SpockBotMC/python-minecraft-data',
    packages=find_packages(),
    package_data={'minecraft_data': extra_files},
    install_requires=[
    ],
    keywords=['minecraft'],
    classifiers=[
        'License :: OSI Approved :: MIT License',
    ]
)
